@@ -12,12 +12,18 @@ from rp.prompt_toolkit.layout.dimension import LayoutDimension
 from rp.prompt_toolkit.layout.lexers import SimpleLexer
 from rp.prompt_toolkit.layout.margins import PromptMargin
 from rp.prompt_toolkit.layout.menus import CompletionsMenu, MultiColumnCompletionsMenu
-from rp.prompt_toolkit.layout.processors import ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor, HighlightMatchingBracketProcessor, Processor, Transformation
+from rp.prompt_toolkit.layout.processors import (
+    ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, 
+    HighlightSelectionProcessor, HighlightMatchingBracketProcessor, 
+    Processor, Transformation, IndentGuideProcessor, ShowWhitespaceProcessor,
+    HighlightWordOccurrencesProcessor
+)
 from rp.prompt_toolkit.layout.screen import Char
 from rp.prompt_toolkit.layout.toolbars import CompletionsToolbar, ArgToolbar, SearchToolbar, ValidationToolbar, SystemToolbar, TokenListToolbar
 from rp.prompt_toolkit.layout.utils import token_list_width
 from rp.prompt_toolkit.reactive import Integer
 from rp.prompt_toolkit.selection import SelectionType
+from rp.prompt_toolkit.token import Token
 from rp.prompt_toolkit.document import Document
 from rp.prompt_toolkit.selection import SelectionState
 
@@ -334,6 +340,13 @@ def status_bar(python_input):
         result = []
         append = result.append
 
+        if hasattr(python_input,'session_title') and python_input.session_title:
+            # append((Token.Window.Title, python_input.session_title, toggle_microcompletions))
+            append((TB.PseudoTerminalCurrentVariable, python_input.session_title, toggle_microcompletions))
+        else:
+            pass
+        
+
         append((TB, ' '))
         result.extend(get_inputmode_tokens(cli, python_input))
 
@@ -349,6 +362,8 @@ def status_bar(python_input):
             # Emacs cut/copy keys.
             append((TB, '[Ctrl-W] Cut [Meta-W] Copy [Ctrl-Y] Paste [Ctrl-G] Cancel'))
         else:
+
+
             result.extend([
                 (TB.Key, '[F3]', enter_history),
                 (TB, 'History ', enter_history),
@@ -390,6 +405,13 @@ def status_bar(python_input):
                 append((TB.PasteModeOn, 'Micro:Off ', toggle_microcompletions))
             
 
+            # if hasattr(python_input,'session_title') and python_input.session_title:
+            #     # append((Token.Window.Title, python_input.session_title, toggle_microcompletions))
+            #     append((TB.PseudoTerminalCurrentVariable, python_input.session_title, toggle_microcompletions))
+            # else:
+            #     pass
+            
+
 
 
         #region RYAN BURGERT CODE GOES HERE FOR PSEUDOTERMINAL STUFF
@@ -500,9 +522,19 @@ def show_sidebar_button_info(python_input):
     import datetime
     remove_beginning_zero=lambda x:x[1:] if x[0] == '0' else x
     import rp
+
+    # if not hasattr(python_input,'session_title'):
+    #     title=''
+    # else:
+    #     title=python_input.session_title
+    # TB = Token.Toolbar.Status
+
     get_tokens=lambda cli: [
 
-
+        # (Token.Window.Title, title),
+        # (token.Key, title),
+        # (TB.PseudoTerminalCurrentVariable, title),
+        (token, ' '),
         *(
             [
                 (token.BatteryPluggedIn if rp.battery_plugged_in() else token.BatteryNotPluggedIn,"🔋 "*0+str(rp.battery_percentage())[:6]+'%'),# put the time here
@@ -608,20 +640,43 @@ def create_layout(python_input,
                 buffer_name=DEFAULT_BUFFER,
                 lexer=lexer,
                 input_processors=[
+                    # Order matters here! We want to ensure brackets are highlighted properly
+                    # First highlight selections 
+                    HighlightSelectionProcessor(),
+                    DisplayMultipleCursors(DEFAULT_BUFFER),
+                    # Then highlight search results
                     ConditionalProcessor(
                         processor=HighlightSearchProcessor(preview_search=True),
                         filter=HasFocus(SEARCH_BUFFER),
                     ),
-                    HighlightSelectionProcessor(),
-                    DisplayMultipleCursors(DEFAULT_BUFFER),
-                    # Show matching parentheses, but only while editing.
+                    # Then highlight matching brackets - this is critical
                     ConditionalProcessor(
                         processor=HighlightMatchingBracketProcessor(chars='[](){}'),
                         filter=HasFocus(DEFAULT_BUFFER) & ~IsDone() &
                             Condition(lambda cli: python_input.highlight_matching_parenthesis)),
+                    # Other processors can come after
                     ConditionalProcessor(
                         processor=AppendAutoSuggestion(),
-                        filter=~IsDone())
+                        filter=~IsDone()),
+                    ConditionalProcessor(
+                        processor=IndentGuideProcessor(tabstop=4, propagate=False),
+                        filter=HasFocus(DEFAULT_BUFFER) & ~IsDone() &
+                            Condition(lambda cli: python_input.indent_guides_mode == 'Regular')),
+                    ConditionalProcessor(
+                        processor=IndentGuideProcessor(tabstop=4, propagate=True),
+                        filter=HasFocus(DEFAULT_BUFFER) & ~IsDone() &
+                            Condition(lambda cli: python_input.indent_guides_mode == 'Propagate')),
+                    ConditionalProcessor(
+                        processor=ShowWhitespaceProcessor(
+                            token=Token.Whitespace, 
+                            mode=lambda cli: python_input.show_whitespace
+                        ),
+                        filter=HasFocus(DEFAULT_BUFFER) & ~IsDone() &
+                            Condition(lambda cli: python_input.show_whitespace != 'Off')),
+                    ConditionalProcessor(
+                        processor=HighlightWordOccurrencesProcessor(min_word_length=1, skip_keywords=True),
+                        filter=HasFocus(DEFAULT_BUFFER) & ~IsDone() &
+                            Condition(lambda cli: python_input.highlight_matching_words))
                 ] + extra_buffer_processors,
                 menu_position=menu_position,
 
@@ -632,6 +687,16 @@ def create_layout(python_input,
             # Scroll offsets. The 1 at the bottom is important to make sure the
             # cursor is never below the "Press [Meta+Enter]" message which is a float.
             scroll_offsets=ScrollOffsets(bottom=1, left=4, right=4),
+            # Highlight cursor line - brackets will be drawn on top of this
+            # Now using same conditions as other processors like HighlightWordOccurrencesProcessor
+            cursorline=Condition(lambda cli: python_input.highlight_cursor_line) & 
+                       HasFocus(DEFAULT_BUFFER) & ~IsDone() &
+                       Condition(lambda cli: len(cli.buffers[DEFAULT_BUFFER].document.lines) > 1),
+            cursorline_token=Token.CursorLine,
+            # Highlight cursor column - same conditions as cursor line
+            cursorcolumn=Condition(lambda cli: python_input.highlight_cursor_column) & 
+                      HasFocus(DEFAULT_BUFFER) & ~IsDone(),
+            cursorcolumn_token=Token.CursorColumn,
             # As long as we're editing, prefer a minimal height of 6.
             get_height=(lambda cli: (
                 None if cli.is_done or python_input.show_exit_confirmation
