@@ -198,6 +198,11 @@ class PythonInput(object):
         self.enable_input_validation=True
         self.enable_auto_suggest=False
         self.enable_mouse_support=False
+        self.indent_guides_mode='Propagate'  # 'Off', 'Regular', or 'Propagate'
+        self.show_whitespace='Off'  # 'Off', 'All', or 'Leading'
+        self.highlight_cursor_line=False  # Highlight the background of the cursor line
+        self.highlight_cursor_column=False  # Highlight the background of the cursor column
+        self.highlight_matching_words=True  # Underline all occurrences of the word under cursor
         self.enable_history_search=False  # When True, like readline, going
         # back in history will filter the
         # history on the records starting
@@ -229,6 +234,24 @@ class PythonInput(object):
         self.ui_styles=get_all_ui_styles()
         self._current_code_style_name='default'
         self._current_ui_style_name='default'
+        self.code_invert_colors=False
+        self.code_invert_brightness=False
+        self.ui_invert_colors=False
+        self.ui_invert_brightness=False
+        self.code_hue_shift=0  # Hue shift for code elements (0-355 degrees in 5-degree increments)
+        self.ui_hue_shift=0    # Hue shift for UI elements (0-355 degrees in 5-degree increments)
+        self.code_min_brightness=0.0  # Minimum brightness for code elements (0.0-1.0)
+        self.code_max_brightness=1.0  # Maximum brightness for code elements (0.0-1.0)
+        self.ui_min_brightness=0.0    # Minimum brightness for UI elements (0.0-1.0)
+        self.ui_max_brightness=1.0    # Maximum brightness for UI elements (0.0-1.0)
+        self.code_min_saturation=0.0  # Minimum saturation for code elements (0.0-1.0)
+        self.code_max_saturation=1.0  # Maximum saturation for code elements (0.0-1.0)
+        self.ui_min_saturation=0.0    # Minimum saturation for UI elements (0.0-1.0)
+        self.ui_max_saturation=1.0    # Maximum saturation for UI elements (0.0-1.0)
+        self.code_ui_min_brightness=None  # Minimum brightness for code UI elements (whitespace, indent guides, etc.) (0.0-1.0)
+        self.code_ui_max_brightness=None  # Maximum brightness for code UI elements (whitespace, indent guides, etc.) (0.0-1.0)
+        self.ui_bg_fg_contrast=0.0    # Minimum brightness difference between foreground and background (0.0-1.0)
+        self.background_mode='Default'  # Background mode: "Nowhere", "Default", "Black", or "White"
 
         if is_windows():
             self._current_code_style_name='win32'
@@ -369,7 +392,31 @@ class PythonInput(object):
         renderer receives a new style class, he will redraw everything.)
         """
         return generate_style(self.code_styles[self._current_code_style_name],
-                              self.ui_styles[self._current_ui_style_name])
+                              self.ui_styles[self._current_ui_style_name],
+                              code_invert_colors=self.code_invert_colors,
+                              code_invert_brightness=self.code_invert_brightness,
+                              ui_invert_colors=self.ui_invert_colors,
+                              ui_invert_brightness=self.ui_invert_brightness,
+                              code_hue_shift=self.code_hue_shift,
+                              ui_hue_shift=self.ui_hue_shift,
+                              code_min_brightness=self.code_min_brightness,
+                              code_max_brightness=self.code_max_brightness,
+                              ui_min_brightness=self.ui_min_brightness,
+                              ui_max_brightness=self.ui_max_brightness,
+                              code_min_saturation=self.code_min_saturation,
+                              code_max_saturation=self.code_max_saturation,
+                              ui_min_saturation=self.ui_min_saturation,
+                              ui_max_saturation=self.ui_max_saturation,
+                              ui_bg_fg_contrast=self.ui_bg_fg_contrast,
+                              code_ui_min_brightness=self.code_ui_min_brightness,
+                              code_ui_max_brightness=self.code_ui_max_brightness)
+                              
+    def _update_style(self):
+        """
+        Update the current style. Used when toggling the invert_colors option.
+        """
+        self._current_style = self._generate_style()
+        return True
     def _create_options(self):
         """
         Create a list of `Option` instances for the options sidebar.
@@ -403,8 +450,9 @@ class PythonInput(object):
                           is_visible=is_visible)
         def doge(self):
             setattr(self,'sand_creature',"Option Camel")
-            from doge.core import main
-            main()
+            # This hasn't aged well :( Fuck Trump and fuck elon - they ruined a meme!
+            # from doge.core import main
+            # main()
 
         return [
             OptionCategory('Input',[
@@ -425,7 +473,7 @@ class PythonInput(object):
                                    'Don\'t require pressing TAB. (Not compatible with "History search".)',
                        get_current_value=lambda:['off','on'][self.complete_while_typing],
                        get_values=lambda:{
-                           'on':lambda:enable('complete_while_typing') and disable('enable_history_search'),
+                           'on':lambda:enable('complete_while_typing'),
                            'off':lambda:disable('complete_while_typing'),
                        }),
                 Option(title='History search',
@@ -434,7 +482,7 @@ class PythonInput(object):
                                    'with the current text. (Not compatible with "Complete while typing".)',
                        get_current_value=lambda:['off','on'][self.enable_history_search],
                        get_values=lambda:{
-                           'on':lambda:enable('enable_history_search') and disable('complete_while_typing'),
+                           'on':lambda:enable('enable_history_search'),
                            'off':lambda:disable('enable_history_search'),
                        }),
                 simple_option(title='Mouse support',
@@ -507,14 +555,41 @@ class PythonInput(object):
                 simple_option(title='Wrap lines',
                               description='Wrap lines instead of scrolling horizontally.',
                               field_name='wrap_lines'),
-                                simple_option(title='History Highlighting',
+                Option(title='Indent guides',
+                       description='Display vertical indent guides. "Regular" shows guides only for existing indentation. "Propagate" also shows guides on empty lines between indented blocks.',
+                       get_current_value=lambda:self.indent_guides_mode,
+                       get_values=lambda:{
+                           'Off': lambda:setattr(self, 'indent_guides_mode', 'Off'),
+                           'Regular': lambda:setattr(self, 'indent_guides_mode', 'Regular'),
+                           'Propagate': lambda:setattr(self, 'indent_guides_mode', 'Propagate'),
+                       }),
+                Option(title='Show whitespace',
+                       description='Display spaces as middle dots (·) and tabs as arrows (→). Choose which whitespace to visualize.',
+                       get_current_value=lambda:self.show_whitespace,
+                       get_values=lambda:{
+                           'Off': lambda:setattr(self, 'show_whitespace', 'Off'),
+                           'All': lambda:setattr(self, 'show_whitespace', 'All'),
+                           'Leading': lambda:setattr(self, 'show_whitespace', 'Leading'),
+                           'Trailing': lambda:setattr(self, 'show_whitespace', 'Trailing'),
+                           'Lead+Trail': lambda:setattr(self, 'show_whitespace', 'Lead+Trail'),
+                       }),
+                simple_option(title='Highlight cursor line',
+                       description='Highlight the background of the line with the cursor.',
+                       field_name='highlight_cursor_line'),
+                simple_option(title='Highlight cursor column',
+                       description='Highlight the background of the column with the cursor.',
+                       field_name='highlight_cursor_column'),
+                simple_option(title='Highlight matching words',
+                       description='Underline all occurrences of the word under the cursor.',
+                       field_name='highlight_matching_words'),
+                simple_option(title='History Highlighting',
                               description='When using F3 (aka History Broswer) to select entries from history,  '
                                           'should we use syntax highlighting? Its pretty, but slow.',
                               field_name='history_syntax_highlighting'),
                 Option(title='History Browser Limit',
                         is_visible=lambda:getattr(self,'show_all_options',True),
 
-                       description='How many lines should we display when using F3 history? Less is faster',
+                       description='How many lines should we display when using F3 history? Less is faster\nMaking this smaller decreases the latency of pressing F3',
                        get_current_value=lambda:str(get_history_line_limit()).rjust(12),
                        get_values=lambda:{'asdpoa':lambda:None,
                             '           1':lambda:set_history_line_limit(1          ),
@@ -561,6 +636,129 @@ class PythonInput(object):
                             '999999999999':lambda:set_history_line_limit(999999999999),
                        }),
 
+                Option(title='Prompt Height Percent',
+                        # is_visible=lambda:getattr(self,'show_all_options',True),
+
+                       description='How many rows of the terminal should the prompt be allowed to take?\n(When using control+e or control+w, this can be useful)\nThis is a hack. Doesnt yet work on Windows (see rp/prompt_toolkit/terminal/vt100_output.py)',
+                       get_current_value=lambda:str(100-r_iterm_comm.options['top_space']).rjust(11)+'%',
+                       get_values=lambda:{'asdpoa':lambda:None,
+                            '          0%':lambda:r_iterm_comm.options.__setitem__('top_space',100-0   ),
+                            '          1%':lambda:r_iterm_comm.options.__setitem__('top_space',100-1   ),
+                            '          2%':lambda:r_iterm_comm.options.__setitem__('top_space',100-2   ),
+                            '          3%':lambda:r_iterm_comm.options.__setitem__('top_space',100-3   ),
+                            '          4%':lambda:r_iterm_comm.options.__setitem__('top_space',100-4   ),
+                            '          5%':lambda:r_iterm_comm.options.__setitem__('top_space',100-5   ),
+                            '         10%':lambda:r_iterm_comm.options.__setitem__('top_space',100-10  ),
+                            '         15%':lambda:r_iterm_comm.options.__setitem__('top_space',100-15  ),
+                            '         20%':lambda:r_iterm_comm.options.__setitem__('top_space',100-20  ),
+                            '         25%':lambda:r_iterm_comm.options.__setitem__('top_space',100-25  ),
+                            '         30%':lambda:r_iterm_comm.options.__setitem__('top_space',100-30  ),
+                            '         35%':lambda:r_iterm_comm.options.__setitem__('top_space',100-35  ),
+                            '         40%':lambda:r_iterm_comm.options.__setitem__('top_space',100-40  ),
+                            '         45%':lambda:r_iterm_comm.options.__setitem__('top_space',100-45  ),
+                            '         50%':lambda:r_iterm_comm.options.__setitem__('top_space',100-50  ),
+                            '         55%':lambda:r_iterm_comm.options.__setitem__('top_space',100-55  ),
+                            '         60%':lambda:r_iterm_comm.options.__setitem__('top_space',100-60  ),
+                            '         65%':lambda:r_iterm_comm.options.__setitem__('top_space',100-65  ),
+                            '         70%':lambda:r_iterm_comm.options.__setitem__('top_space',100-70  ),
+                            '         75%':lambda:r_iterm_comm.options.__setitem__('top_space',100-75  ),
+                            '         80%':lambda:r_iterm_comm.options.__setitem__('top_space',100-80  ),
+                            '         85%':lambda:r_iterm_comm.options.__setitem__('top_space',100-85  ),
+                            '         90%':lambda:r_iterm_comm.options.__setitem__('top_space',100-90  ),
+                            '         95%':lambda:r_iterm_comm.options.__setitem__('top_space',100-95  ),
+                            '        100%':lambda:r_iterm_comm.options.__setitem__('top_space',100-100 ),
+                       }),
+
+                # Option(title='Empty Top Space',
+                #         # is_visible=lambda:getattr(self,'show_all_options',True),
+
+                #        description='How many lines of free rows should be above the top of the prompt?\n(When using control+e or control+w, this can be useful)',
+                #        get_current_value=lambda:str(r_iterm_comm.options['top_space']).rjust(12),
+                #        get_values=lambda:{'asdpoa':lambda:None,
+                #             '           0':lambda:r_iterm_comm.options.__setitem__('top_space',0   ),
+                #             '           1':lambda:r_iterm_comm.options.__setitem__('top_space',1   ),
+                #             '           2':lambda:r_iterm_comm.options.__setitem__('top_space',2   ),
+                #             '           3':lambda:r_iterm_comm.options.__setitem__('top_space',3   ),
+                #             '           4':lambda:r_iterm_comm.options.__setitem__('top_space',4   ),
+                #             '           5':lambda:r_iterm_comm.options.__setitem__('top_space',5   ),
+                #             '          10':lambda:r_iterm_comm.options.__setitem__('top_space',10  ),
+                #             '          15':lambda:r_iterm_comm.options.__setitem__('top_space',15  ),
+                #             '          20':lambda:r_iterm_comm.options.__setitem__('top_space',20  ),
+                #             '          25':lambda:r_iterm_comm.options.__setitem__('top_space',25  ),
+                #             '          30':lambda:r_iterm_comm.options.__setitem__('top_space',30  ),
+                #             '          35':lambda:r_iterm_comm.options.__setitem__('top_space',35  ),
+                #             '          40':lambda:r_iterm_comm.options.__setitem__('top_space',40  ),
+                #             '          45':lambda:r_iterm_comm.options.__setitem__('top_space',45  ),
+                #             '          50':lambda:r_iterm_comm.options.__setitem__('top_space',50  ),
+                #             '          55':lambda:r_iterm_comm.options.__setitem__('top_space',55  ),
+                #             '          60':lambda:r_iterm_comm.options.__setitem__('top_space',60  ),
+                #             '          65':lambda:r_iterm_comm.options.__setitem__('top_space',65  ),
+                #             '          70':lambda:r_iterm_comm.options.__setitem__('top_space',70  ),
+                #             '          75':lambda:r_iterm_comm.options.__setitem__('top_space',75  ),
+                #             '          80':lambda:r_iterm_comm.options.__setitem__('top_space',80  ),
+                #             '          85':lambda:r_iterm_comm.options.__setitem__('top_space',85  ),
+                #             '          90':lambda:r_iterm_comm.options.__setitem__('top_space',90  ),
+                #             '          95':lambda:r_iterm_comm.options.__setitem__('top_space',95  ),
+                #             '         100':lambda:r_iterm_comm.options.__setitem__('top_space',100 ),
+                #             '         125':lambda:r_iterm_comm.options.__setitem__('top_space',125 ),
+                #             '         150':lambda:r_iterm_comm.options.__setitem__('top_space',150 ),
+                #             '         175':lambda:r_iterm_comm.options.__setitem__('top_space',175 ),
+                #             '         200':lambda:r_iterm_comm.options.__setitem__('top_space',200 ),
+                #             '         300':lambda:r_iterm_comm.options.__setitem__('top_space',300 ),
+                #             '         400':lambda:r_iterm_comm.options.__setitem__('top_space',400 ),
+                #             '         500':lambda:r_iterm_comm.options.__setitem__('top_space',500 ),
+                #             '         600':lambda:r_iterm_comm.options.__setitem__('top_space',600 ),
+                #             '         700':lambda:r_iterm_comm.options.__setitem__('top_space',700 ),
+                #             '         800':lambda:r_iterm_comm.options.__setitem__('top_space',800 ),
+                #             '         900':lambda:r_iterm_comm.options.__setitem__('top_space',900 ),
+                #             '        1000':lambda:r_iterm_comm.options.__setitem__('top_space',1000),
+                #        }),
+
+                Option(title='Minimum Prompt Height',
+                        is_visible=lambda:getattr(self,'show_all_options',True),
+
+                       description='With respect to the "Prompt Height" option, whats the minimum height of the prompt (in #rows)?',
+                       get_current_value=lambda:str(r_iterm_comm.options['min_bot_space']).rjust(12),
+                       get_values=lambda:{'asdpoa':lambda:None,
+                            '           0':lambda:r_iterm_comm.options.__setitem__('min_bot_space',0   ),
+                            '           1':lambda:r_iterm_comm.options.__setitem__('min_bot_space',1   ),
+                            '           2':lambda:r_iterm_comm.options.__setitem__('min_bot_space',2   ),
+                            '           3':lambda:r_iterm_comm.options.__setitem__('min_bot_space',3   ),
+                            '           4':lambda:r_iterm_comm.options.__setitem__('min_bot_space',4   ),
+                            '           5':lambda:r_iterm_comm.options.__setitem__('min_bot_space',5   ),
+                            '          10':lambda:r_iterm_comm.options.__setitem__('min_bot_space',10  ),
+                            '          15':lambda:r_iterm_comm.options.__setitem__('min_bot_space',15  ),
+                            '          20':lambda:r_iterm_comm.options.__setitem__('min_bot_space',20  ),
+                            '          25':lambda:r_iterm_comm.options.__setitem__('min_bot_space',25  ),
+                            '          30':lambda:r_iterm_comm.options.__setitem__('min_bot_space',30  ),
+                            '          35':lambda:r_iterm_comm.options.__setitem__('min_bot_space',35  ),
+                            '          40':lambda:r_iterm_comm.options.__setitem__('min_bot_space',40  ),
+                            '          45':lambda:r_iterm_comm.options.__setitem__('min_bot_space',45  ),
+                            '          50':lambda:r_iterm_comm.options.__setitem__('min_bot_space',50  ),
+                            '          55':lambda:r_iterm_comm.options.__setitem__('min_bot_space',55  ),
+                            '          60':lambda:r_iterm_comm.options.__setitem__('min_bot_space',60  ),
+                            '          65':lambda:r_iterm_comm.options.__setitem__('min_bot_space',65  ),
+                            '          70':lambda:r_iterm_comm.options.__setitem__('min_bot_space',70  ),
+                            '          75':lambda:r_iterm_comm.options.__setitem__('min_bot_space',75  ),
+                            '          80':lambda:r_iterm_comm.options.__setitem__('min_bot_space',80  ),
+                            '          85':lambda:r_iterm_comm.options.__setitem__('min_bot_space',85  ),
+                            '          90':lambda:r_iterm_comm.options.__setitem__('min_bot_space',90  ),
+                            '          95':lambda:r_iterm_comm.options.__setitem__('min_bot_space',95  ),
+                            '         100':lambda:r_iterm_comm.options.__setitem__('min_bot_space',100 ),
+                            '         125':lambda:r_iterm_comm.options.__setitem__('min_bot_space',125 ),
+                            '         150':lambda:r_iterm_comm.options.__setitem__('min_bot_space',150 ),
+                            '         175':lambda:r_iterm_comm.options.__setitem__('min_bot_space',175 ),
+                            '         200':lambda:r_iterm_comm.options.__setitem__('min_bot_space',200 ),
+                            '         300':lambda:r_iterm_comm.options.__setitem__('min_bot_space',300 ),
+                            '         400':lambda:r_iterm_comm.options.__setitem__('min_bot_space',400 ),
+                            '         500':lambda:r_iterm_comm.options.__setitem__('min_bot_space',500 ),
+                            '         600':lambda:r_iterm_comm.options.__setitem__('min_bot_space',600 ),
+                            '         700':lambda:r_iterm_comm.options.__setitem__('min_bot_space',700 ),
+                            '         800':lambda:r_iterm_comm.options.__setitem__('min_bot_space',800 ),
+                            '         900':lambda:r_iterm_comm.options.__setitem__('min_bot_space',900 ),
+                            '        1000':lambda:r_iterm_comm.options.__setitem__('min_bot_space',1000),
+                       }),
+
                 Option(title='Show Battery Life',
 
                         is_visible=lambda:getattr(self,'show_all_options',True),
@@ -585,16 +783,16 @@ class PythonInput(object):
 
             ]),
             OptionCategory('Ryan Python',[
-                Option(title='Sand Creature',
-                        is_visible=lambda:getattr(self,'show_all_options',True),
+                # Option(title='Sand Creature',
+                #         is_visible=lambda:getattr(self,'show_all_options',True),
 
-                       description='This is an option selection test that should print stuff',
-                       get_current_value=lambda:getattr(self,'sand_creature','(Broken)'),
-                       get_values=lambda:{
-                           "Option Llama":lambda:setattr(self,'sand_creature',"Option Llama"),# print("Selected Llama"),
-                           "Option Donkey":lambda:setattr(self,'sand_creature',"Option Donkey"),# print("Selected Donkey"),
-                           "Option Camel":lambda:doge(self),# print("Selected Camel"),
-                       }),
+                #        description='This is an option selection test that should print stuff',
+                #        get_current_value=lambda:getattr(self,'sand_creature','(Broken)'),
+                #        get_values=lambda:{
+                #            "Option Llama":lambda:setattr(self,'sand_creature',"Option Llama"),# print("Selected Llama"),
+                #            "Option Donkey":lambda:setattr(self,'sand_creature',"Option Donkey"),# print("Selected Donkey"),
+                #            "Option Camel":lambda:doge(self),# print("Selected Camel"),
+                #        }),
                 Option(title='Show Last Assignable',
                         is_visible=lambda:getattr(self,'show_all_options',True),
 
@@ -664,22 +862,164 @@ class PythonInput(object):
                        }),
             ]),
             OptionCategory('Color Themes',[
+                # Code-related options
                 Option(title='Code',
                        description='Color scheme to use for the Python code.',
-                       get_current_value=lambda:self._current_code_style_name,
+                       get_current_value=lambda:self._current_code_style_name[:15],
                        get_values=lambda:dict(
                            (name,partial(self.use_code_colorscheme,name)) for name in self.code_styles)
                        ),
+                Option(title='Invert Code Colors',
+                       description='Invert foreground and background colors for code syntax highlighting.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: ['off', 'on'][self.code_invert_colors],
+                       get_values=lambda:{
+                           'on': lambda: setattr(self, 'code_invert_colors', True) or self._update_style(),
+                           'off': lambda: setattr(self, 'code_invert_colors', False) or self._update_style(),
+                       }),
+                Option(title='Invert Code Brightness',
+                       description='Invert brightness of code syntax highlighting while preserving color hue.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: ['off', 'on'][self.code_invert_brightness],
+                       get_values=lambda:{
+                           'on': lambda: setattr(self, 'code_invert_brightness', True) or self._update_style(),
+                           'off': lambda: setattr(self, 'code_invert_brightness', False) or self._update_style(),
+                       }),
+                Option(title='Code Hue Shift',
+                       description='Shift the hue of code syntax highlighting by the specified number of degrees.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:03d}'.format(self.code_hue_shift),
+                       get_values=lambda: dict(
+                           ('{:03d}'.format(degrees), lambda degrees=degrees: setattr(self, 'code_hue_shift', degrees) or self._update_style())
+                           for degrees in range(0, 360, 5)
+                       )),
+                Option(title='Code Min Brightness',
+                       description='Set the minimum brightness level for code elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.code_min_brightness),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'code_min_brightness', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='Code Max Brightness',
+                       description='Set the maximum brightness level for code elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.code_max_brightness),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'code_max_brightness', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='Code Min Saturation',
+                       description='Set the minimum saturation level for code elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.code_min_saturation),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'code_min_saturation', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='Code Max Saturation',
+                       description='Set the maximum saturation level for code elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.code_max_saturation),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'code_max_saturation', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                       
+                # Code UI elements brightness controls (separate from code brightness)
+                Option(title='Code UI Min Brightness',
+                       description='Set the minimum brightness level for code UI elements (whitespace, indent guides, row/column highlights).',
+                       get_current_value=lambda: '{:0.2f}'.format(self.code_ui_min_brightness if self.code_ui_min_brightness is not None else 0.0),
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'code_ui_min_brightness', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='Code UI Max Brightness',
+                       description='Set the maximum brightness level for code UI elements (whitespace, indent guides, row/column highlights).',
+                       get_current_value=lambda: '{:0.2f}'.format(self.code_ui_max_brightness if self.code_ui_max_brightness is not None else 1.0),
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'code_ui_max_brightness', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                
+                # UI-related options
                 Option(title='User Interface',
                        description='Color scheme to use for the user interface.',
-                       get_current_value=lambda:self._current_ui_style_name,
+                       get_current_value=lambda:self._current_ui_style_name[:15],
                        get_values=lambda:dict(
                            (name,partial(self.use_ui_colorscheme,name)) for name in self.ui_styles)
                        ),
+                Option(title='Invert UI Colors',
+                       description='Invert foreground and background colors for UI elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: ['off', 'on'][self.ui_invert_colors],
+                       get_values=lambda:{
+                           'on': lambda: setattr(self, 'ui_invert_colors', True) or self._update_style(),
+                           'off': lambda: setattr(self, 'ui_invert_colors', False) or self._update_style(),
+                       }),
+                Option(title='Invert UI Brightness',
+                       description='Invert brightness of UI elements while preserving color hue.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: ['off', 'on'][self.ui_invert_brightness],
+                       get_values=lambda:{
+                           'on': lambda: setattr(self, 'ui_invert_brightness', True) or self._update_style(),
+                           'off': lambda: setattr(self, 'ui_invert_brightness', False) or self._update_style(),
+                       }),
+                Option(title='UI Hue Shift',
+                       description='Shift the hue of UI elements by the specified number of degrees.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:03d}'.format(self.ui_hue_shift),
+                       get_values=lambda: dict(
+                           ('{:03d}'.format(degrees), lambda degrees=degrees: setattr(self, 'ui_hue_shift', degrees) or self._update_style())
+                           for degrees in range(0, 360, 5)
+                       )),
+                Option(title='UI Min Brightness',
+                       description='Set the minimum brightness level for UI elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.ui_min_brightness),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'ui_min_brightness', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='UI Max Brightness',
+                       description='Set the maximum brightness level for UI elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.ui_max_brightness),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'ui_max_brightness', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='UI Min Saturation',
+                       description='Set the minimum saturation level for UI elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.ui_min_saturation),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'ui_min_saturation', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                Option(title='UI Max Saturation',
+                       description='Set the maximum saturation level for UI elements.',
+                       is_visible=lambda: getattr(self, 'show_all_options', False),
+                       get_current_value=lambda: '{:0.2f}'.format(self.ui_max_saturation),
+                       get_values=lambda: dict(
+                           ('{:0.2f}'.format(value/50), lambda value=value: setattr(self, 'ui_max_saturation', value/50) or self._update_style())
+                           for value in range(0,51)
+                       )),
+                       
+                Option(title='BG/FG Contrast',
+                       description='Set the minimum brightness difference between foreground and background. 0.0 allows identical colors, higher values increase contrast.',
+                       get_current_value=lambda: '{:.2f}'.format(self.ui_bg_fg_contrast),
+                       get_values=lambda: dict(
+                           ('{:.2f}'.format(value/50), lambda value=value: setattr(self, 'ui_bg_fg_contrast', value/50) or self._update_style())
+                           for value in range(0, 50)  # Only go up to 0.98
+                       )),
+                
+                # General color options
                 simple_option(title='True color (24 bit)',
-                        is_visible=lambda:getattr(self,'show_all_options',True),
-
-                              description='Use 24 bit colors instead of 265 colors\nThis is only supported on some terminal apps\nSome known to support it: Ubuntu\'s default terminal, MacOS iTerm',
+                        # is_visible=lambda:getattr(self,'show_all_options',True),
+                              description='Use 24 bit colors instead of 256 colors\nThis is only supported on some terminal apps\nSome known to support it: Ubuntu\'s default terminal, MacOS iTerm',
                               field_name='true_color'),
             ]),
             OptionCategory('This Menu',[
