@@ -51,23 +51,26 @@ def get_jedi_script_from_document(document, locals, globals):
             line=document.cursor_position_row + 1,
             path='input-text',
             namespaces=[locals, globals])
-    except ValueError:
-        # Invalid cursor position.
-        # ValueError('`column` parameter is not in a valid range.')
-        return None
-    except AttributeError:
-        # Workaround for #65: https://github.com/jonathanslenders/python-prompt-toolkit/issues/65
-        # See also: https://github.com/davidhalter/jedi/issues/508
-        return None
-    except IndexError:
-        # Workaround Jedi issue #514: for https://github.com/davidhalter/jedi/issues/514
-        return None
-    except KeyError:
-        # Workaroud for a crash when the input is "u'", the start of a unicode string.
-        return None
-    except Exception:
-        # Workaround for: https://github.com/jonathanslenders/ptpython/issues/91
-        return None
+    except Exception as e:
+        return e
+
+    # except ValueError:
+    #     # Invalid cursor position.
+    #     # ValueError('`column` parameter is not in a valid range.')
+    #     return None
+    # except AttributeError:
+    #     # Workaround for #65: https://github.com/jonathanslenders/python-prompt-toolkit/issues/65
+    #     # See also: https://github.com/davidhalter/jedi/issues/508
+    #     return None
+    # except IndexError:
+    #     # Workaround Jedi issue #514: for https://github.com/davidhalter/jedi/issues/514
+    #     return None
+    # except KeyError:
+    #     # Workaroud for a crash when the input is "u'", the start of a unicode string.
+    #     return None
+    # except Exception:
+    #     # Workaround for: https://github.com/jonathanslenders/ptpython/issues/91
+    #     return None
 
 
 _multiline_string_delims = re.compile('''[']{3}|["]{3}''')
@@ -125,3 +128,5 @@ def if_mousedown(handler):
         else:
             return NotImplemented
     return handle_if_mouse_down
+
+
